@@ -26,9 +26,7 @@
 #include <QSortFilterProxyModel>
 #include <QModelIndex>
 
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 class AttendeeTableModel : public QAbstractTableModel
 {
     Q_OBJECT
@@ -57,20 +55,20 @@ public:
         Tentative
     };
 
-    explicit AttendeeTableModel(const KCalCore::Attendee::List &resources, QObject *parent = nullptr);
+    explicit AttendeeTableModel(const KCalCore::Attendee::List &resources,
+                                QObject *parent = nullptr);
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QVariant headerData(int section, Qt::Orientation orientation,
-                        int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+                        int role = Qt::DisplayRole) const override;
 
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
-    bool setData(const QModelIndex &index, const QVariant &value,
-                 int role = Qt::EditRole) Q_DECL_OVERRIDE;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
 
-    bool insertRows(int position, int rows, const QModelIndex &index = QModelIndex()) Q_DECL_OVERRIDE;
-    bool removeRows(int position, int rows, const QModelIndex &index = QModelIndex()) Q_DECL_OVERRIDE;
+    bool insertRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
+    bool removeRows(int position, int rows, const QModelIndex &index = QModelIndex()) override;
 
     bool insertAttendee(int position, const KCalCore::Attendee::Ptr &attendee);
 
@@ -96,7 +94,7 @@ class ResourceFilterProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 public:
     explicit ResourceFilterProxyModel(QObject *parent = nullptr);
-    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 };
 
 class AttendeeFilterProxyModel : public QSortFilterProxyModel
@@ -104,9 +102,8 @@ class AttendeeFilterProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 public:
     explicit AttendeeFilterProxyModel(QObject *parent = nullptr);
-    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const Q_DECL_OVERRIDE;
+    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 };
-
 }
 
 #endif
