@@ -35,7 +35,6 @@ public:
     explicit IncidenceCategories(Ui::EventOrTodoDesktop *ui);
 
     void load(const KCalCore::Incidence::Ptr &incidence) override;
-    void load(const Akonadi::Item &item) override;
     void save(const KCalCore::Incidence::Ptr &incidence) override;
     void save(Akonadi::Item &item) override;
 
@@ -48,8 +47,6 @@ public:
     void printDebugInfo() const override;
 
 private:
-    void matchExistingCategories(const QStringList &categories,
-                                 const Akonadi::Tag::List &existingTags);
     void createMissingCategories();
 
 private Q_SLOTS:
@@ -59,7 +56,6 @@ private Q_SLOTS:
 
 private:
     Ui::EventOrTodoDesktop *mUi;
-    Akonadi::Tag::List mSelectedTags;
 
     /**
      * List of categories for which no tag might exist.
