@@ -53,52 +53,57 @@ using namespace IncidenceEditorNG;
 class FreebusyViewCalendar : public EventViews::ViewCalendar
 {
 public:
-    virtual ~FreebusyViewCalendar() {}
-    bool isValid(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    virtual ~FreebusyViewCalendar()
+    {
+    }
+
+    bool isValid(const KCalCore::Incidence::Ptr &incidence) const override
     {
         return isValid(incidence->uid());
     }
 
-    bool isValid(const QString &incidenceIdentifier) const Q_DECL_OVERRIDE
+    bool isValid(const QString &incidenceIdentifier) const override
     {
         return incidenceIdentifier.startsWith(QStringLiteral("fb-"));
     }
 
-    QString displayName(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QString displayName(const KCalCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence);
         return QStringLiteral("Freebusy");
     }
 
-    QColor resourceColor(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QColor resourceColor(const KCalCore::Incidence::Ptr &incidence) const override
     {
         bool ok = false;
-        int status = incidence->customProperty(QStringLiteral("FREEBUSY").toLatin1(), QStringLiteral("STATUS").toLatin1()).toInt(&ok);
+        int status = incidence->customProperty(QStringLiteral(
+                                                   "FREEBUSY").toLatin1(), QStringLiteral(
+                                                   "STATUS").toLatin1()).toInt(&ok);
 
         if (!ok) {
-            return QColor(QStringLiteral("#555"));
+            return QColor(85, 85, 85);
         }
 
         switch (status) {
         case KCalCore::FreeBusyPeriod::Busy:
-            return QColor(QStringLiteral("#f00"));
+            return QColor(255, 0, 0);
         case KCalCore::FreeBusyPeriod::BusyTentative:
         case KCalCore::FreeBusyPeriod::BusyUnavailable:
-            return QColor(QStringLiteral("#f70"));
+            return QColor(255, 119, 0);
         case KCalCore::FreeBusyPeriod::Free:
-            return QColor(QStringLiteral("#0f0"));
+            return QColor(0, 255, 0);
         default:
-            return QColor(QStringLiteral("#555"));
+            return QColor(85, 85, 85);
         }
     }
 
-    QString iconForIncidence(const KCalCore::Incidence::Ptr &incidence) const Q_DECL_OVERRIDE
+    QString iconForIncidence(const KCalCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence);
         return QString();
     }
 
-    KCalCore::Calendar::Ptr getCalendar() const Q_DECL_OVERRIDE
+    KCalCore::Calendar::Ptr getCalendar() const override
     {
         return mCalendar;
     }
@@ -109,7 +114,8 @@ public:
 ResourceManagement::ResourceManagement(QWidget *parent)
     : QDialog(parent)
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(
+        QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -130,7 +136,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
     mModel = new CalendarSupport::FreeBusyItemModel(this);
     mFreebusyCalendar.setModel(mModel);
 
-    mAgendaView = new EventViews::AgendaView(QDate(), QDate(), false,  false);
+    mAgendaView = new EventViews::AgendaView(QDate(), QDate(), false, false);
 
     FreebusyViewCalendar *fbCalendar = new FreebusyViewCalendar();
     fbCalendar->mCalendar = mFreebusyCalendar.calendar();
@@ -150,11 +156,13 @@ ResourceManagement::ResourceManagement(QWidget *parent)
     mUi->treeResults->setSelectionMode(QAbstractItemView::SingleSelection);
     selectionModel = mUi->treeResults->selectionModel();
 
-    connect(mUi->resourceSearch, &KLineEdit::textChanged, this, &ResourceManagement::slotStartSearch);
+    connect(mUi->resourceSearch, &KLineEdit::textChanged, this,
+            &ResourceManagement::slotStartSearch);
 
     connect(mUi->treeResults, &QTreeView::clicked, this, &ResourceManagement::slotShowDetails);
 
-    connect(resourcemodel, &ResourceModel::layoutChanged, this, &ResourceManagement::slotLayoutChanged);
+    connect(resourcemodel, &ResourceModel::layoutChanged, this,
+            &ResourceManagement::slotLayoutChanged);
     readConfig();
 }
 
@@ -181,7 +189,6 @@ void ResourceManagement::writeConfig()
     group.sync();
 }
 
-
 ResourceItem::Ptr ResourceManagement::selectedItem() const
 {
     return mSelectedItem;
@@ -189,12 +196,13 @@ ResourceItem::Ptr ResourceManagement::selectedItem() const
 
 void ResourceManagement::slotStartSearch(const QString &text)
 {
-    ((ResourceModel *)mUi->treeResults->model())->startSearch(text);
+    (static_cast<ResourceModel *>(mUi->treeResults->model()))->startSearch(text);
 }
 
 void ResourceManagement::slotShowDetails(const QModelIndex &current)
 {
-    ResourceItem::Ptr item = current.model()->data(current, ResourceModel::Resource).value<ResourceItem::Ptr>();
+    ResourceItem::Ptr item
+        = current.model()->data(current, ResourceModel::Resource).value<ResourceItem::Ptr>();
     mSelectedItem = item;
     showDetails(item->ldapObject(), item->ldapClient());
 }
@@ -212,16 +220,19 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
     // Fill formDetails with data
     for (auto it = obj.attributes().cbegin(), end = obj.attributes().cbegin(); it != end; ++it) {
         const QString &key = it.key();
-        if (key ==  QStringLiteral("objectClass") || key == QLatin1String("email")) {
+        if (key == QStringLiteral("objectClass") || key == QLatin1String("email")) {
             continue;
-        } else if (key ==  QStringLiteral("owner")) {
+        } else if (key == QStringLiteral("owner")) {
             QStringList attrs;
             attrs << QStringLiteral("cn") << QStringLiteral("mail")
                   << QStringLiteral("mobile") <<  QStringLiteral("telephoneNumber")
                   << QStringLiteral("kolabDescAttribute") << QStringLiteral("description");
-            mOwnerItem = ResourceItem::Ptr(new ResourceItem(KLDAP::LdapDN(QString::fromUtf8(it.value().at(0))),
-                                           attrs,  client));
-            connect(mOwnerItem.data(),  &ResourceItem::searchFinished, this, &ResourceManagement::slotOwnerSearchFinished);
+            mOwnerItem
+                = ResourceItem::Ptr(new ResourceItem(KLDAP::LdapDN(QString::fromUtf8(it.value().at(0))),
+                                                     attrs, client));
+            connect(
+                mOwnerItem.data(), &ResourceItem::searchFinished, this,
+                &ResourceManagement::slotOwnerSearchFinished);
             mOwnerItem->startSearch();
             continue;
         }
@@ -231,12 +242,13 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
         for (const QByteArray &value: values) {
             list << QString::fromUtf8(value);
         }
-        mUi->formDetails->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QLatin1Char('\n'))));
+        mUi->formDetails->addRow(translateLDAPAttributeForDisplay(key),
+                                 new QLabel(list.join(QLatin1Char('\n'))));
     }
 
     QString name = QString::fromUtf8(obj.attributes().value(QStringLiteral("cn"))[0]);
     QString email = QString::fromUtf8(obj.attributes().value(QStringLiteral("mail"))[0]);
-    KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(name,  email));
+    KCalCore::Attendee::Ptr attendee(new KCalCore::Attendee(name, email));
     CalendarSupport::FreeBusyItem::Ptr freebusy(new CalendarSupport::FreeBusyItem(attendee, this));
     mModel->clear();
     mModel->addItem(freebusy);
@@ -264,10 +276,10 @@ void ResourceManagement::slotOwnerSearchFinished()
     const KLDAP::LdapAttrMap &ldapAttrMap = obj.attributes();
     for (auto it = ldapAttrMap.cbegin(), end = ldapAttrMap.cend(); it != end; ++it) {
         const QString &key = it.key();
-        if (key ==  QStringLiteral("objectClass")
-                || key ==  QStringLiteral("owner")
-                || key ==  QStringLiteral("givenname")
-                || key ==  QStringLiteral("sn")) {
+        if (key == QStringLiteral("objectClass")
+            || key == QStringLiteral("owner")
+            || key == QStringLiteral("givenname")
+            || key == QStringLiteral("sn")) {
             continue;
         }
         QStringList list;
@@ -276,7 +288,8 @@ void ResourceManagement::slotOwnerSearchFinished()
         for (const QByteArray &value : values) {
             list << QString::fromUtf8(value);
         }
-        mUi->formOwner->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QLatin1Char('\n'))));
+        mUi->formOwner->addRow(translateLDAPAttributeForDisplay(key),
+                               new QLabel(list.join(QLatin1Char('\n'))));
     }
 }
 
